#!/usr/bin/python
# -*- coding: UTF-8 -*-

from flask import Blueprint
from flask import jsonify, session, redirect, url_for, abort

import config
import utils
from utils.decorator import login_required
from utils.template import my_render_template
from views.images import get_submission_uuid_for_file

uuid_view = Blueprint( "uuid", __name__, template_folder = "templates" )

def get_all_uuid():
    lst = {}
    
    tables = [ "submissions", "files", "files_segments", "exercises", "cnm_annotation", "cnm_data", "cnm_folder", "cnm_segments", "signin_requests" ]
    for table in tables:
        for u in config.db.query_fetchall( "SELECT uuid FROM {}".format( table ) ):
            lst[ u[ "uuid" ] ] = table
    
    return lst

def get_all_uuid_partial():
    lst = get_all_uuid()
    lst = [ k[ 0:18 ] for k in lst.keys() ]
    lst.sort()
    return lst

@uuid_view.route( "/uuid" )
@login_required
def search_page():
    lst = get_all_uuid_partial()
    return jsonify( lst )

@uuid_view.route( "/uuid/search" )
@login_required
def search_uuid():
    lst = get_all_uuid_partial()
    return my_render_template(
        "uuid/search.html",
        uuid_list = lst
    )

@uuid_view.route( "/uuid/autoopen/<uuid>" )
@login_required
def autoopen( uuid ):
    lst = []
    for cuuid, table in get_all_uuid().iteritems():
        if uuid in cuuid[ 0:18 ]:
            lst.append( {
                "table": table,
                "uuid": cuuid
            } )
    
    if len( lst ) != 1:
        return jsonify( lst )
    else:
        target = lst[ 0 ]
        
        if session[ "account_type_name" ] == "Administrator":
            if target[ "table" ] == "submissions":
                return redirect( url_for( "submission.admin_submission_home", submission_id = target[ "uuid" ] ) )

            elif target[ "table" ] == "files":
                file_type = type_of_file( target[ "uuid" ] )
                if file_type in [ "tenprint_card_front", "tenprint_card_back" ]:
                    return redirect( url_for( "submission.admin_tenprint", submission_id = get_submission_uuid_for_file( target[ "uuid" ] ), tenprint_id = target[ "uuid" ] ) )
                elif file_type in [ "mark_target", "mark_incidental" ]:
                    return redirect( url_for( "submission.admin_submission_mark", submission_id = get_submission_uuid_for_file( target[ "uuid" ] ), mark_id = target[ "uuid" ] ) )

            elif target[ "table" ] == "cnm_folder":
                return redirect( url_for( "afis.admin_folder_show", folder_id = target[ "uuid" ] ) )

            elif target[ "table" ] == "cnm_annotation":
                cnm_folder, fpc = cnm_folder_of_annotation( target[ "uuid" ] )
                return redirect( url_for( "afis.admin_view_segment", folder_id = cnm_folder, fpc = fpc ) )
        
        else:
            if target[ "table" ] == "submissions":
                return redirect( url_for( "submission.submission_upload_tenprintmark", submission_id = target[ "uuid" ] ) )
            
            elif target[ "table" ] == "files":
                file_type = type_of_file( target[ "uuid" ] )
                if file_type in [ "tenprint_card_front", "tenprint_card_back" ]:
                    return redirect( url_for( "submission.submission_tenprint", submission_id = get_submission_uuid_for_file( target[ "uuid" ] ), tenprint_id = target[ "uuid" ] ) )
                elif file_type in [ "mark_target", "mark_incidental" ]:
                    return redirect( url_for( "submission.submission_mark", submission_id = get_submission_uuid_for_file( target[ "uuid" ] ), mark_id = target[ "uuid" ] ) )

            elif target[ "table" ] == "cnm_folder":
                return redirect( url_for( "afis.folder_show", folder_id = target[ "uuid" ] ) )
            
            elif target[ "table" ] == "cnm_annotation":
                cnm_folder, fpc = cnm_folder_of_annotation( target[ "uuid" ] )
                return redirect( url_for( "afis.view_segment", folder_id = cnm_folder, fpc = fpc ) )

        return abort( 404 )
            
def type_of_file( uuid ):
    sql = """
        SELECT
            files_type.name
        FROM files
        INNER JOIN files_type ON files.type = files_type.id
        WHERE files.uuid = %s
    """
    return config.db.query_fetchone( sql, ( uuid, ) )[ "name" ]

def cnm_folder_of_annotation( uuid ):
    sql = """
        SELECT
            folder, fpc
        FROM cnm_annotation
        WHERE uuid = %s
    """
    return config.db.query_fetchone( sql, ( uuid, ) )

